@@ -1,15 +1,13 @@
 package BibTeX::Parser::Entry;
 {
-  $BibTeX::Parser::Entry::VERSION = '1.02';
+  $BibTeX::Parser::Entry::VERSION = '1.93';
 }
 
 use warnings;
 use strict;
 
-use BibTeX::Parser;
-use BibTeX::Parser::Author;
-
-
+require BibTeX::Parser::Author; # mutual dependencies
+require BibTeX::Parser;
 
 sub new {
 	my ($class, $type, $key, $parse_ok, $fieldsref) = @_;
@@ -248,6 +246,7 @@ sub to_string {
 	    $type = ucfirst lc $type;
 	}
     }
+    print STDERR $self->key, "\n";
     $result .= '@'.$type."{".$self->key.",\n";    
     foreach my $field (@fields) {
 	my $value = $self->field($field);
@@ -284,8 +283,8 @@ BibTeX::Parser::Entry - Contains a single entry of a BibTeX document.
 
 =head1 SYNOPSIS
 
-This class ist a wrapper for a single BibTeX entry. It is usually created
-by a BibTeX::Parser.
+This class is a wrapper for a single BibTeX entry. It is usually created
+by BibTeX::Parser.
 
     use BibTeX::Parser::Entry;
 
@@ -303,9 +302,6 @@ by a BibTeX::Parser.
 	    print $entry->to_string;
     }
 
-   
-
-
 
 =head1 FUNCTIONS
 
@@ -386,6 +382,17 @@ Return raw BibTeX entry (if available).
 Returns a text of the BibTeX entry in BibTeX format.  Options are
 a hash.  
 
+The return string is the entry reformated with lines indented by 4
+spaces and the @entrytype uppercased. Example:
+
+    @BOOK{Knuth:TAOCP1,
+        author = {Knuth, Donald E.},
+        publisher = {Addison-Wesley},
+        title = {The Art of Computer Programming},
+        year = {1968},
+        url = {https://www-cs-faculty.stanford.edu/~knuth/taocp.html},
+    }
+
 =over 4
 
 =item C<canonize_names>
@@ -410,24 +417,23 @@ before the entry NEVER has the @ symbol inside
 Capitalization of the type names.  
 Can take values 'Uppercase' (the default), 'Lowercase' or 'Titlecase'
 
-
 =back
 
 =head1 VERSION
 
-version 1.02
+version 1.93
 
 =head1 AUTHOR
 
 Gerhard Gossen <gerhard.gossen@googlemail.com> and
-Boris Veytsman <boris@varphi.com>
+Boris Veytsman <boris@varphi.com> and
+Karl Berry <karl@freefriends.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013-2016 by Gerhard Gossen and Boris Veytsman
+Copyright 2013-2025 Gerhard Gossen, Boris Veytsman, Karl Berry
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
